@@ -13,9 +13,6 @@ SUPPORTED_ALGORITHMS = ['fa', 'gwo', 'ba', 'hba', 'hsaba']
 
 
 class NatureInspiredSearchCV(BaseSearchCV):
-    __param_grid = None
-    __algorithm = None
-
     def _run_search(self, evaluate_candidates):
         self.__print_run_search_log()
 
@@ -32,11 +29,16 @@ class NatureInspiredSearchCV(BaseSearchCV):
             )
 
             self.__algorithm.run(task=task)
+
+            if self.__algorithm.exception:
+                raise self.__algorithm.exception
+
             # invert scores in the optimization logs
             self.optimization_logs_.append([(log[0], log[1] * -1) for log in task.optimization_logs_])
 
     def __init__(self, estimator, param_grid, algorithm='hba', population_size=50, max_n_gen=100, runs=3,
                  max_stagnating_gen=20, scoring=None, n_jobs=None, iid='deprecated', refit=True, cv=None, verbose=0,
+                 random_state=None,
                  pre_dispatch='2*n_jobs', error_score=np.nan, return_train_score=True):
         super().__init__(estimator, scoring, n_jobs, iid, refit, cv, verbose, pre_dispatch, error_score,
                          return_train_score)
@@ -44,7 +46,7 @@ class NatureInspiredSearchCV(BaseSearchCV):
         self.__n_gen = max_n_gen
         self.__max_stagnating_gen = max_stagnating_gen
         self.__param_grid = ParamGrid(param_grid)
-        self.__algorithm = self.__get_algorithm(algorithm, population_size)
+        self.__algorithm = self.__get_algorithm(algorithm, population_size, random_state)
 
         self.runs_ = runs
         self.optimization_logs_ = None
@@ -59,7 +61,7 @@ class NatureInspiredSearchCV(BaseSearchCV):
             print(f'Fitting at most {candidates} candidates')
 
     @staticmethod
-    def __get_algorithm(algorithm, population_size):
+    def __get_algorithm(algorithm, population_size, random_state):
         if isinstance(algorithm, str):
             if algorithm not in SUPPORTED_ALGORITHMS:
                 raise ValueError(f'"{algorithm}" is not in supported algorithms: {", ".join(SUPPORTED_ALGORITHMS)}')
@@ -67,19 +69,19 @@ class NatureInspiredSearchCV(BaseSearchCV):
             algorithm_obj = None
 
             if algorithm == 'fa':
-                algorithm_obj = FireflyAlgorithm()
+                algorithm_obj = FireflyAlgorithm(seed=random_state)
                 algorithm_obj.setParameters(alpha=1, betamin=1, gamma=2)
             elif algorithm == 'ba':
-                algorithm_obj = BatAlgorithm()
+                algorithm_obj = BatAlgorithm(seed=random_state)
                 algorithm_obj.setParameters(A=0.9, r=0.1, Qmin=0.0, Qmax=2.0)
             elif algorithm == 'hba':
-                algorithm_obj = HybridBatAlgorithm()
+                algorithm_obj = HybridBatAlgorithm(seed=random_state)
                 algorithm_obj.setParameters(A=0.9, r=0.1, Qmin=0.0, Qmax=2.0)
             elif algorithm == 'hsaba':
-                algorithm_obj = HybridSelfAdaptiveBatAlgorithm()
+                algorithm_obj = HybridSelfAdaptiveBatAlgorithm(seed=random_state)
                 algorithm_obj.setParameters(A=0.9, r=0.1, Qmin=0.0, Qmax=2.0)
             elif algorithm == 'gwo':
-                algorithm_obj = GreyWolfOptimizer()
+                algorithm_obj = GreyWolfOptimizer(seed=random_state)
 
             algorithm_obj.setParameters(NP=population_size)
 
